@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 import sys 
 import smtplib
@@ -37,7 +37,7 @@ class VerifyEmail(object):
     """ Verify if email exists """
 
     EMAIL_RE = re.compile('([\w\-\.+]+@\w[\w\-]+\.+[\w\-]+)')
-    default_response = (550, 'Unknown')
+    default_response = (550, 'Reason not known')
     
     # given a hostname, all mx records will be returned
     def get_mx_for_hostname(self, hostname):
@@ -48,7 +48,8 @@ class VerifyEmail(object):
             except:
                 pass
         return mx
-    
+
+
     # given a host name, returns True if valid, else False
     def is_hostname_valid(self, hostname):
         """ if hostname is valid """
@@ -58,11 +59,13 @@ class VerifyEmail(object):
             return False
         return True
 
+
     # given an email address, returns True if email matches a valid pattern
     def is_email_valid(self, email):
         """ if a given email maches the email pattern """
         return self.EMAIL_RE.search(email)
 
+
     # given an email, hostname is returned
     def get_hostname_from_email(self, email):
         try:
@@ -71,6 +74,7 @@ class VerifyEmail(object):
             hostname = None
         return hostname
 
+
     # given a hostname, a smtp server connection is returned or None
     def get_smtp_connection(self, hostname):
         """ returns a server with valid connection if possible """
@@ -85,12 +89,14 @@ class VerifyEmail(object):
             if connection_success(resp):
                 return server
         return None
-    
+
+
     # given a  response tuple, it returns True if status was success
     def was_found(self, resp):
         """ email WAS found """
         return resp[0] == 250
 
+
     # given a response tuple, it returns True if it can tell if email was not found
     def not_found(self, resp):
         """ email was NOT found """
@@ -105,14 +111,15 @@ class VerifyEmail(object):
                 "invalid",
                 "doesn't handle",
         ]
-        if resp[0] != 250 and any(a in resp[1].lower() for a in not_found_words):
-            return True
+        return resp[0] != 250 and any(a in resp[1].lower() for a in not_found_words)
+
 
     # given a response tuple, it returns true if it couldn't tell, if email found or not
     def could_not_verify_status(self, resp):
         """ email unverifiable """
         return not (self.was_found(resp) or self.not_found(resp))
-    
+
+
     # returns a response tuple indicating the existance of an email address
     def verify_email_smtp(
         self,
@@ -128,6 +135,8 @@ class VerifyEmail(object):
         if self.is_email_valid(email):
             hostname = self.get_hostname_from_email(email)
             mx = self.get_mx_for_hostname(hostname)
+            if not mx:
+                return (550, 'No-Mx-Found')
             for m in mx:
                 server = self.get_smtp_connection(m[1])
                 if server:
@@ -146,8 +155,11 @@ class VerifyEmail(object):
                             except:
                                 continue
                             break
+            if not server:
+                return (550, 'No-Server-Connection')
         return resp
-            
+
+
 # given an email it returns True if it can tell it exist or False
 def  verify_email_address(
                 email, 
